@@ -15,8 +15,8 @@ logger = logging.getLogger("penguin")
 
 """
 TODO:
-- change imports -> from penguin_py import penguin
 - Update README.md
+- Update github repo description, other things
 """
 
 """
@@ -68,8 +68,6 @@ def penguin(
             time_msg = get_time_msg.get_time_msg(run_time)
             logger.info(f"Finished {func_name} in {time_msg}.")
 
-            logger.info("adventure of a lifetime!")
-
             if show_return or verbose:
                 logger.info(f"Returned value: {value!r}")
 
